---
jupyter:
  jupytext:
    formats: ipynb:markdown,md
  kernelspec:
    display_name: OCaml default
    language: OCaml
    name: ocaml-jupyter
---

# Example of an OCaml notebook

```{ocaml}
let sum x y = x + y
```

Let's try our function:

```{ocaml}
sum 3 4 = 7 + 0
```
